@@ -176,10 +176,10 @@ pth_t pth_spawn(pth_attr_t attr, void *(*func)(void*), void *arg)
         func = NULL;
 
     /* allocate a new thread control block */
-    stacksize = (attr == PTH_ATTR_DEFAULT ? 32*16384 : attr->a_stacksize);
+    stacksize = (attr == PTH_ATTR_DEFAULT ? 32*1024 : attr->a_stacksize);
     stackaddr = (attr == PTH_ATTR_DEFAULT ? NULL : attr->a_stackaddr);
     if ((t = pth_tcb_alloc(stacksize, stackaddr)) == NULL)
-        return_errno(NULL, ENOMEM);
+        return NULL; /* errno is inherited */
 
     /* configure remaining attributes */
     if (attr != PTH_ATTR_DEFAULT) {
