@@ -21,7 +21,9 @@
 **  Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA 02111-1307
 **  USA, or contact Ralf S. Engelschall <rse@engelschall.com>.
 */
-
+                             /* ``Recursive, adj.;
+                                  see Recursive.''
+                                     -- Unknown   */
 #include "pth_p.h"
 
 intern pth_t        pth_main;       /* the main thread */
@@ -50,8 +52,8 @@ intern void pth_scheduler_init(void)
         perror("pipe");
         abort();
     }
-    pth_nonblocking(pth_sigpipe[0]);
-    pth_nonblocking(pth_sigpipe[1]);
+    pth_fdmode(pth_sigpipe[0], PTH_FDMODE_NONBLOCK);
+    pth_fdmode(pth_sigpipe[1], PTH_FDMODE_NONBLOCK);
 
     /* initialize the essential threads */
     pth_sched   = NULL;
@@ -284,7 +286,7 @@ intern void *pth_scheduler(void *dummy)
                  */
                 if (sigaction(SIGSEGV, NULL, &sa) == 0) {
                     if (sa.sa_handler == SIG_DFL) {
-                        fprintf(stderr, "** STACK OVERFLOW: thread 0x%lx (\"%s\")\n",
+                        fprintf(stderr, "**Pth** STACK OVERFLOW: thread pid_t=0x%lx, name=\"%s\"\n",
                                 (unsigned long)pth_current, pth_current->name);
                         kill(getpid(), SIGSEGV);
                         sigfillset(&ss);
@@ -653,7 +655,7 @@ intern void pth_sched_eventmanager(pth_time_t *now, int dopoll)
                         }
                     }
                     /* Filedescriptor Set I/O */
-                    if (ev->ev_type == PTH_EVENT_SELECT) {
+                    else if (ev->ev_type == PTH_EVENT_SELECT) {
                         if (pth_util_fds_test(ev->ev_args.SELECT.nfd, 
                                               ev->ev_args.SELECT.rfds, &rfds,
                                               ev->ev_args.SELECT.wfds, &wfds,
@@ -728,8 +730,8 @@ intern void pth_sched_eventmanager(pth_time_t *now, int dopoll)
             pth_pqueue_delete(&pth_WQ, tlast);
             tlast->state = PTH_STATE_READY;
             pth_pqueue_insert(&pth_RQ, tlast->prio+1, tlast);
-            pth_debug2("pth_scheduler: thread \"%s\" moved from waiting to ready queue", 
-                       tlast->name);
+            pth_debug2("pth_sched_eventmanager: thread \"%s\" moved from waiting "
+                       "to ready queue", tlast->name);
         }
     }
 
