@@ -120,13 +120,9 @@ int main(int argc, char *argv[])
     
     mp_worker = pth_msgport_find("worker");
     mp = pth_msgport_create("main");
-    q = malloc(sizeof(struct query));
+    q = (struct query *)malloc(sizeof(struct query));
     ev = pth_event(PTH_EVENT_MSG, mp);
     
-    pth_nonblocking(STDIN_FILENO);
-    pth_nonblocking(STDERR_FILENO);
-    pth_nonblocking(STDOUT_FILENO);
-
     evt = NULL;
     for (;;) {
         if (evt == NULL)
