@@ -22,21 +22,21 @@
 **  USA, or contact Ralf S. Engelschall <rse@engelschall.com>.
 */
 
-#include <stdio.h>
-#include <stdlib.h>
-#include <string.h>
-#include <unistd.h>
-#include <errno.h>
-
 #ifdef GLOBAL
 #include <pthread.h>
 #else
 #include "pthread.h"
 #endif
 
+#include <stdio.h>
+#include <stdlib.h>
+#include <string.h>
+#include <unistd.h>
+#include <errno.h>
+
 #define die(str) \
     do { \
-        fprintf(stderr, "**die: %s: %s\n", str, strerror(errno)); \
+        fprintf(stderr, "**die: %s: errno=%d\n", str, errno); \
         exit(1); \
     } while (0)
 
@@ -70,16 +70,16 @@ int main(int argc, char *argv[])
         die("pthread_attr_setdetachstate");
     
     fprintf(stderr, "main: create thread 1\n");
-    if (pthread_create(&thread[0], &thread_attr, child, "foo") != 0)
+    if (pthread_create(&thread[0], &thread_attr, child, (void *)"foo") != 0)
         die("pthread_create");
     fprintf(stderr, "main: create thread 2\n");
-    if (pthread_create(&thread[1], &thread_attr, child, "bar") != 0)
+    if (pthread_create(&thread[1], &thread_attr, child, (void *)"bar") != 0)
         die("pthread_create");
     fprintf(stderr, "main: create thread 3\n");
-    if (pthread_create(&thread[2], &thread_attr, child, "baz") != 0)
+    if (pthread_create(&thread[2], &thread_attr, child, (void *)"baz") != 0)
         die("pthread_create");
     fprintf(stderr, "main: create thread 4\n");
-    if (pthread_create(&thread[3], &thread_attr, child, "quux") != 0)
+    if (pthread_create(&thread[3], &thread_attr, child, (void *)"quux") != 0)
         die("pthread_create");
 
     fprintf(stderr, "main: destroying attribute object\n");
